# Lenscraft

This application allows users to create and tweak a custom computer vision pipeline for micro-assembly

## How to run
Install the package from pypi
```
pip install lenscraft
```

To run the application, simply run the command
```
lenscraft
```
or
```
python -m lenscraft
```


## How to Use

1. Add images you want to work with
2. Build vision pipeline using the Node Editor

![image](https://i.imgur.com/ELtun4k.png)

## Developer?

1. Clone the repository
2. Install the package in edit mode

```
pip install -e .
```

3. Run the application
```
python -m lenscraft
```